---
test_data: TD_27_59_80_86
test_title: single data envelope arg suggestion and consumption
---

*   If there is already single `data_envelope` found, then do not suggest remaining arg types (to save human time).
*   But if user puts an arg value matching the single value from the remaining arg types, consume it.
    TODO: This might be controversial.
          This also might complicate implementation and
          reasoning about consumption behavior.

See also both:
*   `FS_13_51_07_97` for singled out implicit values.
*   `FS_90_48_11_45` for force-assignment.
    However, in case of this `test_data: TD_27_59_80_86`, there is no force assignment,
    the assignment is matching.

